==> haskell-jose-0.7.0.0-106-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-9uWMu1BKKhJKZPfIDGqULL
key: jose-0.7.0.0-9uWMu1BKKhJKZPfIDGqULL
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 95fa469b085175fc4a00c765e5e4582f
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-9uWMu1BKKhJKZPfIDGqULL
depends:
    QuickCheck-2.13.1-BED53w0KTtOAjBW8qj2Yxi
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bytestring-0.10.8.2 concise-0.1.0.1-LxuYkrYtoWA9w563kkyvYK
    containers-0.6.0.1 cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    lens-4.17.1-HTmXQinx68g2x0Owmg0yAK
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.21-IM9b0NeUnVW6QfVDzGv41l
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    x509-1.7.5-4SipZUEfLKoGzZKIMuaQ6w
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.7.0.0-107-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-K7OhVNC1uC51R2s52GgoD
key: jose-0.7.0.0-K7OhVNC1uC51R2s52GgoD
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 58b8caff92ea58971b3229589a5babac
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-K7OhVNC1uC51R2s52GgoD
depends:
    QuickCheck-2.13.1-BED53w0KTtOAjBW8qj2Yxi
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bytestring-0.10.8.2 concise-0.1.0.1-5yAYq9nfd7THGGDhtvTJuK
    containers-0.6.0.1 cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    lens-4.17.1-4Jk5GSd1SEYIuq2Vm9OfL2
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.21-IM9b0NeUnVW6QfVDzGv41l
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    x509-1.7.5-4SipZUEfLKoGzZKIMuaQ6w
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
